==> opensaml-xmlsec-impl-3.4.6-sources.jar: org/opensaml/xmlsec/signature/impl/NamedCurveBuilder.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.xmlsec.signature.impl;

import org.opensaml.core.xml.AbstractXMLObjectBuilder;
import org.opensaml.xmlsec.signature.NamedCurve;
import org.opensaml.xmlsec.signature.XMLSignatureBuilder;
import org.opensaml.xmlsec.signature.support.SignatureConstants;

/**
 * Builder of {@link NamedCurve}.
 */
public class NamedCurveBuilder extends AbstractXMLObjectBuilder<NamedCurve>
    implements XMLSignatureBuilder<NamedCurve> {

    /**
     * Constructor.
     */
    public NamedCurveBuilder() {
    }

    /** {@inheritDoc} */
    public NamedCurve buildObject(final String namespaceURI, final String localName, final String namespacePrefix) {
        return new NamedCurveImpl(namespaceURI, localName, namespacePrefix);
    }

    /** {@inheritDoc} */
    public NamedCurve buildObject() {
        return buildObject(SignatureConstants.XMLSIG11_NS, NamedCurve.DEFAULT_ELEMENT_LOCAL_NAME,
                SignatureConstants.XMLSIG11_PREFIX);
    }

}

==> opensaml-xmlsec-impl-5.1.6-sources.jar: org/opensaml/xmlsec/signature/impl/NamedCurveBuilder.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.xmlsec.signature.impl;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import org.opensaml.core.xml.AbstractXMLObjectBuilder;
import org.opensaml.xmlsec.signature.NamedCurve;
import org.opensaml.xmlsec.signature.XMLSignatureBuilder;
import org.opensaml.xmlsec.signature.support.SignatureConstants;

/**
 * Builder of {@link NamedCurve}.
 */
public class NamedCurveBuilder extends AbstractXMLObjectBuilder<NamedCurve>
    implements XMLSignatureBuilder<NamedCurve> {

    /** {@inheritDoc} */
    @Nonnull public NamedCurve buildObject(@Nullable final String namespaceURI, @Nonnull final String localName,
            @Nullable final String namespacePrefix) {
        return new NamedCurveImpl(namespaceURI, localName, namespacePrefix);
    }

    /** {@inheritDoc} */
    @Nonnull public NamedCurve buildObject() {
        return buildObject(SignatureConstants.XMLSIG11_NS, NamedCurve.DEFAULT_ELEMENT_LOCAL_NAME,
                SignatureConstants.XMLSIG11_PREFIX);
    }

}
